@@ -3,7 +3,7 @@ use rayon::prelude::*;
 
 pub mod criterion;
 
-pub use criterion::FilterCritrion;
+pub use criterion::FilterCriterion;
 
 #[derive(Debug, Clone, Copy)]
 pub enum CriteriaRelation {
@@ -14,14 +14,14 @@ pub enum CriteriaRelation {
 #[derive(Debug, Clone)]
 pub struct Filter {
     pub relation: CriteriaRelation,
-    pub critria: Vec<FilterCritrion>,
+    pub criteria: Vec<FilterCriterion>,
 }
 
 impl Default for Filter {
     fn default() -> Self {
         Filter {
             relation: CriteriaRelation::And,
-            critria: Vec::new(),
+            criteria: Vec::new(),
         }
     }
 }
@@ -30,8 +30,8 @@ impl Filter {
     /// Checks if the entry meets the filter criteria
     pub fn check_entry(&self, entry: &Entry) -> bool {
         match self.relation {
-            CriteriaRelation::And => self.critria.par_iter().all(|cr| cr.check_entry(entry)),
-            CriteriaRelation::Or => self.critria.par_iter().any(|cr| cr.check_entry(entry)),
+            CriteriaRelation::And => self.criteria.par_iter().all(|cr| cr.check_entry(entry)),
+            CriteriaRelation::Or => self.criteria.par_iter().any(|cr| cr.check_entry(entry)),
         }
     }
 }
